@@ -41,11 +41,7 @@ from airflow.providers.microsoft.azure.utils import (
     get_field,
     get_sync_default_azure_credential,
 )
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.microsoft.azure.version_compat import BaseHook
 
 if TYPE_CHECKING:
     PartitionKeyType = str | list[str]
@@ -215,7 +211,7 @@ class AzureCosmosDBHook(BaseHook):
             .get_database_client(self.__get_database_name(database_name))
             .query_containers(
                 "SELECT * FROM r WHERE r.id=@id",
-                parameters=[{"name": "@id", "value": collection_name}],  # type: ignore[list-item]
+                parameters=[{"name": "@id", "value": collection_name}],
             )
         )
         if not existing_container:
@@ -242,7 +238,7 @@ class AzureCosmosDBHook(BaseHook):
             .get_database_client(self.__get_database_name(database_name))
             .query_containers(
                 "SELECT * FROM r WHERE r.id=@id",
-                parameters=[{"name": "@id", "value": collection_name}],  # type: ignore[list-item]
+                parameters=[{"name": "@id", "value": collection_name}],
             )
         )
 
@@ -263,7 +259,7 @@ class AzureCosmosDBHook(BaseHook):
         existing_database = list(
             self.get_conn().query_databases(
                 "SELECT * FROM r WHERE r.id=@id",
-                parameters=[{"name": "@id", "value": database_name}],  # type: ignore[list-item]
+                parameters=[{"name": "@id", "value": database_name}],
             )
         )
         if not existing_database:
@@ -283,7 +279,7 @@ class AzureCosmosDBHook(BaseHook):
         existing_database = list(
             self.get_conn().query_databases(
                 "SELECT * FROM r WHERE r.id=@id",
-                parameters=[{"name": "@id", "value": database_name}],  # type: ignore[list-item]
+                parameters=[{"name": "@id", "value": database_name}],
             )
         )
 
