@@ -27,7 +27,10 @@ from airflow.providers.microsoft.azure.triggers.powerbi import (
     PowerBITrigger,
     PowerBIWorkspaceListTrigger,
 )
-from airflow.providers.microsoft.azure.version_compat import BaseOperator
+from airflow.providers.microsoft.azure.version_compat import (
+    BaseOperator,
+    BaseOperatorLink,
+)
 
 if TYPE_CHECKING:
     from msgraph_core import APIVersion
@@ -35,13 +38,6 @@ if TYPE_CHECKING:
     from airflow.models.taskinstancekey import TaskInstanceKey
     from airflow.utils.context import Context
 
-from airflow.providers.microsoft.azure.version_compat import AIRFLOW_V_3_0_PLUS
-
-if AIRFLOW_V_3_0_PLUS:
-    from airflow.sdk import BaseOperatorLink
-else:
-    from airflow.models.baseoperatorlink import BaseOperatorLink  # type: ignore[no-redef]
-
 
 class PowerBILink(BaseOperatorLink):
     """Construct a link to monitor a dataset in Power BI."""
@@ -50,7 +46,7 @@ class PowerBILink(BaseOperatorLink):
 
     def get_link(self, operator: BaseOperator, *, ti_key: TaskInstanceKey):
         url = (
-            "https://app.powerbi.com"  # type: ignore[attr-defined]
+            "https://app.powerbi.com"
             f"/groups/{operator.group_id}/datasets/{operator.dataset_id}"  # type: ignore[attr-defined]
             "/details?experience=power-bi"
         )
