@@ -88,7 +88,7 @@ class AzureSynapseRunSparkBatchOperator(BaseOperator):
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
-        self.job_id = None
+        self.job_id: Any = None
         self.azure_synapse_conn_id = azure_synapse_conn_id
         self.wait_for_termination = wait_for_termination
         self.spark_pool = spark_pool
